=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2010-04-19 13:04:30 +0000
+++ bzrlib/builtins.py	2010-04-22 14:18:17 +0000
@@ -1134,8 +1134,10 @@
         else:
             revision_id = None
         if tree is not None and revision_id is None:
-            tree.warn_if_changed_or_out_of_date(
-                strict, 'push_strict', 'Use --no-strict to force the push.')
+            tree.check_changed_or_out_of_date(
+                strict, 'push_strict',
+                more_error='Use --no-strict to force the push.',
+                more_warning='Uncommitted changes will not be pushed.')
         # Get the stacked_on branch, if any
         if stacked_on is not None:
             stacked_on = urlutils.normalize_url(stacked_on)

=== modified file 'bzrlib/foreign.py'
--- bzrlib/foreign.py	2010-04-12 16:54:35 +0000
+++ bzrlib/foreign.py	2010-04-22 14:18:17 +0000
@@ -297,8 +297,10 @@
             source_branch = Branch.open(directory)
             source_wt = None
         if source_wt is not None:
-            source_wt.warn_if_changed_or_out_of_date(
-                strict, 'dpush_strict', 'Use --no-strict to force the push.')
+            source_wt.check_changed_or_out_of_date(
+                strict, 'dpush_strict',
+                more_error='Use --no-strict to force the push.',
+                more_warning='Uncommitted changes will not be pushed.')
         stored_loc = source_branch.get_push_location()
         if location is None:
             if stored_loc is None:

=== modified file 'bzrlib/mutabletree.py'
--- bzrlib/mutabletree.py	2010-04-22 13:58:04 +0000
+++ bzrlib/mutabletree.py	2010-04-22 14:18:17 +0000
@@ -258,7 +258,8 @@
             return False
 
     @needs_read_lock
-    def warn_if_changed_or_out_of_date(self, strict, opt_name, more_msg):
+    def check_changed_or_out_of_date(self, strict, opt_name,
+                                     more_error, more_warning):
         """Check the tree for uncommitted changes and branch synchronization.
 
         If strict is None and not set in the config files, a warning is issued.
@@ -269,7 +270,9 @@
 
         :param opt_name: strict option name to search in config file.
 
-        :param more_msg: Details about how to avoid the check.
+        :param more_error: Details about how to avoid the check.
+
+        :param more_warning: Details about what is happening.
         """
         if strict is None:
             strict = self.branch.get_config().get_user_option_as_bool(opt_name)
@@ -284,12 +287,12 @@
                 err_class = errors.OutOfDateTree
             if err_class is not None:
                 if strict is None:
-                    err = err_class(self)
+                    err = err_class(self, more=more_warning)
                     # We don't want to interrupt the user if he expressed no
                     # preference about strict.
                     trace.warning('%s', err._format())
                 else:
-                    err = err_class(self, more=more_msg)
+                    err = err_class(self, more=more_error)
                     raise err
 
     @needs_read_lock

=== modified file 'bzrlib/send.py'
--- bzrlib/send.py	2010-04-12 16:54:35 +0000
+++ bzrlib/send.py	2010-04-22 14:18:17 +0000
@@ -111,8 +111,10 @@
                 base_revision_id = revision[0].as_revision_id(branch)
         if revision_id is None:
             if tree is not None:
-                tree.warn_if_changed_or_out_of_date(
-                    strict, 'send_strict', 'Use --no-strict to force the send.')
+                tree.check_changed_or_out_of_date(
+                    strict, 'send_strict',
+                    more_error='Use --no-strict to force the send.',
+                    more_warning='Uncommitted changes will not be sent.')
             revision_id = branch.last_revision()
         if revision_id == NULL_REVISION:
             raise errors.BzrCommandError('No revisions to submit.')

